@@ -1,12 +1,14 @@
 require 'spec_helper'
 
 describe 'sahara::policy' do
-
-  shared_examples_for 'sahara policies' do
+  shared_examples 'sahara::policy' do
     let :params do
       {
-        :policy_path => '/etc/sahara/policy.yaml',
-        :policies    => {
+        :enforce_scope        => false,
+        :enforce_new_defaults => false,
+        :policy_path          => '/etc/sahara/policy.yaml',
+        :policy_dirs          => '/etc/sahara/policy.d',
+        :policies             => {
           'context_is_admin' => {
             'key'   => 'context_is_admin',
             'value' => 'foo:bar'
@@ -24,20 +26,23 @@ describe 'sahara::policy' do
         :file_format => 'yaml',
       })
       is_expected.to contain_oslo__policy('sahara_config').with(
-        :policy_file => '/etc/sahara/policy.yaml',
+        :enforce_scope        => false,
+        :enforce_new_defaults => false,
+        :policy_file          => '/etc/sahara/policy.yaml',
+        :policy_dirs          => '/etc/sahara/policy.d',
       )
     end
   end
 
   on_supported_os({
-    :supported_os   => OSDefaults.get_supported_os
+    :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      it_configures 'sahara policies'
+      it_behaves_like 'sahara::policy'
     end
   end
 end
